@@ -177,8 +177,7 @@ class Config:  # pylint: disable=too-many-public-methods
             if value:
                 data.append(value)
 
-        return '''
-'''.join(data)
+        return os.linesep.join(data)
 
     @property
     def peers(self):
@@ -203,19 +202,18 @@ class Config:  # pylint: disable=too-many-public-methods
             if value:
                 data.append(value)
 
-        return '''
-'''.join(data)
+        return os.linesep.join(data)
 
     @property
     def local_config(self):
         """
         Returns the full WireGuard config
         """
-        return f'''
-{self.interface}
-
-{self.peers}
-'''
+        return os.linesep.join((
+            self.interface,
+            '',
+            self.peers,
+        ))
 
     @property
     def qrcode(self):
@@ -236,18 +234,24 @@ class Config:  # pylint: disable=too-many-public-methods
         """
         return f'{self._peer.interface}.conf'
 
-    def full_path(self, config_path=CONFIG_PATH):
+    def full_path(self, config_path=None):
         """
         Returns the full path to the WireGuard config file
         """
+
+        if config_path in [None, False]:
+            config_path = CONFIG_PATH
         return os.path.join(config_path, self.filename)
 
-    def write(self, config_path=CONFIG_PATH):
+    def write(self, config_path=None):
         """
         Writes the WireGuard config file
         """
 
-        with open(self.full_path(config_path), 'w') as conf_fh:
+        if config_path in [None, False]:
+            config_path = CONFIG_PATH
+
+        with open(self.full_path(config_path), mode='w', encoding='utf-8') as conf_fh:
             conf_fh.write(self.local_config)
 
 
@@ -270,22 +274,26 @@ class ServerConfig(Config):
         """
         return f'{self._peer.interface}-peers.conf'
 
-    def peers_full_path(self, config_path=CONFIG_PATH):
+    def peers_full_path(self, config_path=None):
         """
         Returns the full path to the peers config file
         """
+        if config_path in [None, False]:
+            config_path = CONFIG_PATH
         return os.path.join(config_path, self.peers_filename)
 
-    def write(self, config_path=CONFIG_PATH):
+    def write(self, config_path=None):
         """
         Write out the main config and the peers config files
         """
 
+        if config_path in [None, False]:
+            config_path = CONFIG_PATH
         peers_file = self.peers_full_path(config_path)
 
-        with open(self.full_path(config_path), 'w') as conf_fh:
-            conf_fh.write(self.interface)
-            conf_fh.write(f'PostUp = wg addconf %i {peers_file}')
+        with open(self.full_path(config_path), mode='w', encoding='utf-8') as conf_fh:
+            conf_fh.write(self.interface + os.linesep)
+            conf_fh.write(f'PostUp = wg addconf %i {peers_file}' + os.linesep)
 
-        with open(peers_file, 'w') as peers_fh:
-            peers_fh.write(self.peers)
+        with open(peers_file, mode='w', encoding='utf-8') as peers_fh:
+            peers_fh.write(self.peers + os.linesep)
